==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-czech.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","E-mail");
define("_RE","Re");
define("_SUBJECT","Pedmt");
define("_PRIVATEMESSAGES","Vae osobn zprvy");
define("_CHECKALL","Vybrat ve");
define("_FROM","Od");
define("_DATE","Datum");
define("_DONTHAVEMESSAGES","Nemte dn zprvy");
define("_NOTREAD","Nepeteno");
define("_MSGSTATUS","Status zprvy");
define("_PRIVATEMESSAGE","Osobn zprva");
define("_INDEX","Index");
define("_SENT","Poslat");
define("_PREVIOUSMESSAGE","Pedchoz zprva");
define("_NEXTMESSAGE","Dal zprva");
define("_PROFILE","Profil");
define("_ABOUTPOSTING","O pspvku");
define("_ALLREGCANPOST","Vichni registrovan uivatel mohou poslat osobn zprvy");
define("_TO","Komu");
define("_MESSAGEICON","Ikonka zprvy");
define("_MESSAGE","Zprva");
define("_HTML","HTML");
define("_PMON","Zap.");
define("_PMOFF","Vyp.");
define("_BBCODE","BB Kd");
define("_WROTE","pe");
define("_OPTIONS","Monosti");
define("_HTMLDISSABLE","Nepovolit HTML v tomto pspvku");
define("_BBCODEDISSABLE","Nepovolit <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBkd</i></a> v tomto pspvku");
define("_SMILEDISSABLE","Nepovolit <a href=\"bb_smilies.php\" target=\"_blank\"><i>smajlky</i></a> v tomto pspvku");
define("_CANCELREPLY","Zruit odpov");
define("_CANCELSEND","Zruit odesln");
define("_CLEAR","Vyistit");
define("_SUBMIT","Odeslat");
define("_USERNOTINDB","Vybran uivatel neexistuje v na databzi.");
define("_CHECKNAMEANDTRY","Zadejte, prosm, novou pezdvku a zkuste to znovu.");
define("_MSGPOSTED","Vae zprva byla odeslna.");
define("_RETURNTOPMSG","Kliknte zde pro znovunaten vaich osobnch zprv.");
define("_MSGDELETED","Vae zprvy byly smazny.");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-czech.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","E-mail");
define("_RE","Re");
define("_SUBJECT","Pedmt");
define("_PRIVATEMESSAGES","Vae osobn zprvy");
define("_CHECKALL","Vybrat ve");
define("_FROM","Od");
define("_DATE","Datum");
define("_DONTHAVEMESSAGES","Nemte dn zprvy");
define("_NOTREAD","Nepeteno");
define("_MSGSTATUS","Status zprvy");
define("_PRIVATEMESSAGE","Osobn zprva");
define("_INDEX","Index");
define("_SENT","Poslat");
define("_PREVIOUSMESSAGE","Pedchoz zprva");
define("_NEXTMESSAGE","Dal zprva");
define("_PROFILE","Profil");
define("_ABOUTPOSTING","O pspvku");
define("_ALLREGCANPOST","Vichni registrovan uivatel mohou poslat osobn zprvy");
define("_TO","Komu");
define("_MESSAGEICON","Ikonka zprvy");
define("_MESSAGE","Zprva");
define("_HTML","HTML");
define("_PMON","Zap.");
define("_PMOFF","Vyp.");
define("_BBCODE","BB Kd");
define("_WROTE","pe");
define("_OPTIONS","Monosti");
define("_HTMLDISSABLE","Nepovolit HTML v tomto pspvku");
define("_BBCODEDISSABLE","Nepovolit <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBkd</i></a> v tomto pspvku");
define("_SMILEDISSABLE","Nepovolit <a href=\"bb_smilies.php\" target=\"_blank\"><i>smajlky</i></a> v tomto pspvku");
define("_CANCELREPLY","Zruit odpov");
define("_CANCELSEND","Zruit odesln");
define("_CLEAR","Vyistit");
define("_SUBMIT","Odeslat");
define("_USERNOTINDB","Vybran uivatel neexistuje v na databzi.");
define("_CHECKNAMEANDTRY","Zadejte, prosm, novou pezdvku a zkuste to znovu.");
define("_MSGPOSTED","Vae zprva byla odeslna.");
define("_RETURNTOPMSG","Kliknte zde pro znovunaten vaich osobnch zprv.");
define("_MSGDELETED","Vae zprvy byly smazny.");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>
